use std::ops::Deref;

use actix_web::{HttpResponse, Responder};
use askama::Template;

use crate::controllers::settings_controller::BaseSettingsPage;
use crate::data::current_user::CurrentUser;
use crate::data::user::User;

#[derive(Template)]
#[template(path = "settings/two_factors_page.html")]
struct TwoFactorsPage<'a> {
    _p: BaseSettingsPage,
    user: &'a User,
}

#[derive(Template)]
#[template(path = "settings/add_2fa_totp_page.html")]
struct AddTotpPage {
    _p: BaseSettingsPage,
}


/// Manage two factors authentication methods route
pub async fn two_factors_route(user: CurrentUser) -> impl Responder {
    HttpResponse::Ok()
        .body(TwoFactorsPage {
            _p: BaseSettingsPage::get(
                "Two factors auth",
                &user,
                None,
                None),
            user: user.deref(),
        }.render().unwrap())
}


/// Configure a new TOTP authentication factor
pub async fn add_totp_factor_route(user: CurrentUser) -> impl Responder {
    HttpResponse::Ok()
        .body(AddTotpPage {
            _p: BaseSettingsPage::get(
                "Configure new TOTP factor",
                &user,
                None,
                None),
        }.render().unwrap())
}